RegionCore

Trait RegionCore 

pub trait RegionCore {
    // Required methods
    fn start(&self) -> u32;
    fn end(&self) -> u32;
    fn chrom(&self) -> ChrRef<'static>;

    // Provided methods
    fn empty(&self) -> bool { ... }
    fn length(&self) -> u32 { ... }
}

Required Methods

fn start(&self) -> u32

fn end(&self) -> u32

fn chrom(&self) -> ChrRef<'static>

Provided Methods

fn empty(&self) -> bool

fn length(&self) -> u32

Implementations on Foreign Types

Source

impl<'a> RegionCore for (ChrRef<'a>, u32, u32)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<'a, T: Region> RegionCore for &'a T

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region> RegionCore for (A, B)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region> RegionCore for (A, B, C)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region> RegionCore for (A, B, C, D)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region> RegionCore for (A, B, C, D, E)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region> RegionCore for (A, B, C, D, E, F)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region, G: Region> RegionCore for (A, B, C, D, E, F, G)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region, G: Region, H: Region> RegionCore for (A, B, C, D, E, F, G, H)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region, G: Region, H: Region, I: Region> RegionCore for (A, B, C, D, E, F, G, H, I)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region, G: Region, H: Region, I: Region, J: Region> RegionCore for (A, B, C, D, E, F, G, H, I, J)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<A: Region, B: Region, C: Region, D: Region, E: Region, F: Region, G: Region, H: Region, I: Region, J: Region, K: Region> RegionCore for (A, B, C, D, E, F, G, H, I, J, K)

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Source

impl<T: Region> RegionCore for Option<T>

Source

fn start(&self) -> u32

Source

fn end(&self) -> u32

Source

fn chrom(&self) -> ChrRef<'static>

Implementors

Source

impl RegionCore for Bed3

Source

impl<'a> RegionCore for Bed4<'a>

Source

impl<'a, S> RegionCore for Bed5<'a, S>

Source

impl<'a, S> RegionCore for Bed6<'a, S>

Source

impl<K: ToOwned, T: 'static + Region> RegionCore for GroupBuffer<K, T>

Source

impl<T: Region> RegionCore for RegionComponent<T>